#ifndef PRINT_H
#define PRINT_H

#include <denemo/denemo.h> 

void
print(GtkAction *action, gpointer callback_data);


#endif /*PRINT_H*/	
